/**
 * Specifies the termination criteria to apply before Amazon EC2 Auto Scaling chooses an instance for termination.
 *
 * @stability stable
 */
export declare enum TerminationPolicy {
    /**
     * Terminate instances in the Auto Scaling group to align the remaining instances to the allocation strategy for the type of instance that is terminating (either a Spot Instance or an On-Demand Instance).
     *
     * @stability stable
     */
    ALLOCATION_STRATEGY = "AllocationStrategy",
    /**
     * Terminate instances that are closest to the next billing hour.
     *
     * @stability stable
     */
    CLOSEST_TO_NEXT_INSTANCE_HOUR = "ClosestToNextInstanceHour",
    /**
     * Terminate instances according to the default termination policy.
     *
     * @stability stable
     */
    DEFAULT = "Default",
    /**
     * Terminate the newest instance in the group.
     *
     * @stability stable
     */
    NEWEST_INSTANCE = "NewestInstance",
    /**
     * Terminate the oldest instance in the group.
     *
     * @stability stable
     */
    OLDEST_INSTANCE = "OldestInstance",
    /**
     * Terminate instances that have the oldest launch configuration.
     *
     * @stability stable
     */
    OLDEST_LAUNCH_CONFIGURATION = "OldestLaunchConfiguration",
    /**
     * Terminate instances that have the oldest launch template.
     *
     * @stability stable
     */
    OLDEST_LAUNCH_TEMPLATE = "OldestLaunchTemplate"
}
